contentstorage/casrv/cawidgetscanner/inc/widgetscannerutils.h
changeset 73 4bc7b118b3df
parent 61 8e5041d13c84
child 98 d2f833ab7940
--- a/contentstorage/casrv/cawidgetscanner/inc/widgetscannerutils.h	Mon May 03 12:48:45 2010 +0300
+++ b/contentstorage/casrv/cawidgetscanner/inc/widgetscannerutils.h	Fri May 14 16:10:06 2010 +0300
@@ -11,7 +11,7 @@
 *
 * Contributors:
 *
-* Description:  
+* Description:
  *
 */
 
@@ -27,6 +27,7 @@
 _LIT(KAttrWidgetPath, "widget:path");
 _LIT(KAttrWidgetLibrary, "widget:library");
 _LIT(KAttrWidgetUri, "widget:uri");
+_LIT(KAttrWidgetServiceXml, "widget:servicexml");
 _LIT(KSlash, "/");
 _LIT(KDllExt, ".dll");
 _LIT(KNoLibrary, "NoLibrary");
@@ -38,7 +39,7 @@
  *
  *  @since Series Series60 5.x
  */
-class WidgetScannerUtils 
+class WidgetScannerUtils
     {
 public:
 
@@ -52,11 +53,11 @@
         const DriveInfo::TDefaultDrives& aDefaultDrive);
 
     /**
-     * Returns current MMC id
-     * @param aFs file server session reference
-     * @return current mmc id
-     */  
-    static TUint CurrentMmcId( RFs& aFs );
+     * Returns current MMC id.
+     * @param aFs file server session reference.
+     * @param aMmcId mmc id reference.
+     */
+    static void CurrentMmcId( const RFs& aFs, TDes& aMmcId );
 
     };